@@ -22,12 +22,9 @@
 
 #include "grd-stream.h"
 
-#include "grd-context.h"
-
 enum
 {
   READY,
-  CLOSED,
 
   N_SIGNALS
 };
@@ -36,17 +33,25 @@ static guint signals[N_SIGNALS];
 
 typedef struct _GrdStreamPrivate
 {
-  GrdContext *context;
-
+  uint32_t stream_id;
   uint32_t pipewire_node_id;
+  char *mapping_id;
 
-  GrdDBusScreenCastStream *proxy;
+  GrdDBusMutterScreenCastStream *proxy;
 
   unsigned long pipewire_stream_added_id;
 } GrdStreamPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GrdStream, grd_stream, G_TYPE_OBJECT)
 
+uint32_t
+grd_stream_get_stream_id (GrdStream *stream)
+{
+  GrdStreamPrivate *priv = grd_stream_get_instance_private (stream);
+
+  return priv->stream_id;
+}
+
 uint32_t
 grd_stream_get_pipewire_node_id (GrdStream *stream)
 {
@@ -56,11 +61,11 @@ grd_stream_get_pipewire_node_id (GrdStream *stream)
 }
 
 const char *
-grd_stream_get_object_path (GrdStream *stream)
+grd_stream_get_mapping_id (GrdStream *stream)
 {
   GrdStreamPrivate *priv = grd_stream_get_instance_private (stream);
 
-  return g_dbus_proxy_get_object_path (G_DBUS_PROXY (priv->proxy));
+  return priv->mapping_id;
 }
 
 void
@@ -72,9 +77,9 @@ grd_stream_disconnect_proxy_signals (GrdStream *stream)
 }
 
 static void
-on_pipewire_stream_added (GrdDBusScreenCastStream *proxy,
-                          unsigned int             node_id,
-                          GrdStream               *stream)
+on_pipewire_stream_added (GrdDBusMutterScreenCastStream *proxy,
+                          unsigned int                   node_id,
+                          GrdStream                     *stream)
 {
   GrdStreamPrivate *priv = grd_stream_get_instance_private (stream);
 
@@ -84,17 +89,33 @@ on_pipewire_stream_added (GrdDBusScreenCastStream *proxy,
 }
 
 GrdStream *
-grd_stream_new (GrdContext              *context,
-                GrdDBusScreenCastStream *proxy)
+grd_stream_new (uint32_t                        stream_id,
+                GrdDBusMutterScreenCastStream  *proxy,
+                GError                        **error)
 {
   GrdStream *stream;
   GrdStreamPrivate *priv;
+  GVariant *parameters;
+  char *mapping_id;
+
+  parameters = grd_dbus_mutter_screen_cast_stream_get_parameters (proxy);
+  g_variant_lookup (parameters, "mapping-id", "s", &mapping_id);
+
+  if (!mapping_id)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                   "Missing mapping-id for stream %u", stream_id);
+      return NULL;
+    }
+
+  g_debug ("PipeWire stream %u mapping ID: %s", stream_id, mapping_id);
 
   stream = g_object_new (GRD_TYPE_STREAM, NULL);
   priv = grd_stream_get_instance_private (stream);
 
-  priv->context = context;
-  priv->proxy = proxy;
+  priv->stream_id = stream_id;
+  priv->mapping_id = mapping_id;
+  priv->proxy = g_object_ref (proxy);
   priv->pipewire_stream_added_id =
     g_signal_connect (proxy, "pipewire-stream-added",
                       G_CALLBACK (on_pipewire_stream_added),
@@ -103,12 +124,30 @@ grd_stream_new (GrdContext              *context,
   return stream;
 }
 
+void
+grd_stream_destroy (GrdStream *stream)
+{
+  g_object_run_dispose (G_OBJECT (stream));
+  g_object_unref (stream);
+}
+
 static void
 grd_stream_finalize (GObject *object)
 {
   GrdStream *stream = GRD_STREAM (object);
   GrdStreamPrivate *priv = grd_stream_get_instance_private (stream);
 
+  g_clear_pointer (&priv->mapping_id, g_free);
+
+  G_OBJECT_CLASS (grd_stream_parent_class)->finalize (object);
+}
+
+static void
+grd_stream_dispose (GObject *object)
+{
+  GrdStream *stream = GRD_STREAM (object);
+  GrdStreamPrivate *priv = grd_stream_get_instance_private (stream);
+
   g_clear_object (&priv->proxy);
 
   G_OBJECT_CLASS (grd_stream_parent_class)->finalize (object);
@@ -124,6 +163,7 @@ grd_stream_class_init (GrdStreamClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+  object_class->dispose = grd_stream_dispose;
   object_class->finalize = grd_stream_finalize;
 
   signals[READY] = g_signal_new ("ready",
@@ -132,10 +172,4 @@ grd_stream_class_init (GrdStreamClass *klass)
                                  0,
                                  NULL, NULL, NULL,
                                  G_TYPE_NONE, 0);
-  signals[CLOSED] = g_signal_new ("closed",
-                                  G_TYPE_FROM_CLASS (klass),
-                                  G_SIGNAL_RUN_LAST,
-                                  0,
-                                  NULL, NULL, NULL,
-                                  G_TYPE_NONE, 0);
 }
